@@ -133,7 +133,8 @@ class Task(BaseModel):
     @classmethod
     def create(cls, job_info: JobInfo, target_system: str, comment: str = None):
         query = f"INSERT INTO db_global.ScheduleJob(job_info,target_system,comment) VALUES(%s,%s,%s)"
-        _, cnx = execute_query(query, values=(job_info.json(exclude_unset=True), target_system, comment),
+        _, cnx = execute_query(query,
+                               values=(job_info.json(exclude_unset=True, ensure_ascii=False), target_system, comment),
                                reuse_cnx=True)
         query = f"SELECT LAST_INSERT_ID()"
         res, _ = select_query(query, cnx=cnx)
